# Generated by Django 2.1.7 on 2020-07-13 03:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cargo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionario',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionariologin',
            options={'managed': False},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 16:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0004_auto_20200716_1205'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='filial',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='filialhorafuncionamento',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='filialservico',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='servico',
            options={'managed': True},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0003_auto_20200715_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='modulo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfil',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfilgrupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfillogin',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfilpontofuncao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='pontofuncao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='versao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='versaoitem',
            options={'managed': False},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 17:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='avaliacao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cartao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cliente',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientetermo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cupom',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='endereco',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='favorito',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='receita',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='termo',
            options={'managed': False},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-31 03:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0009_alter_user_last_name_max_length'),
        ('funcionario', '0013_funcionariologin_is_staff'),
    ]

    operations = [
        migrations.AddField(
            model_name='funcionariologin',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='funcionario_funcionariologin_user_set', related_query_name='user', to='auth.Group', verbose_name='groups'),
        ),
        migrations.AddField(
            model_name='funcionariologin',
            name='is_superuser',
            field=models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status'),
        ),
        migrations.AddField(
            model_name='funcionariologin',
            name='user_permissions',
            field=models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='funcionario_funcionariologin_user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0008_auto_20200717_1034'),
        ('filial', '0010_remove_filial_cep'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='filialservico',
            name='filial',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='servico',
        ),
        migrations.RemoveField(
            model_name='filial',
            name='servicos',
        ),
        migrations.RemoveField(
            model_name='filialhorafuncionamento',
            name='cd_filial',
        ),
        migrations.AddField(
            model_name='filial',
            name='cep',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Cep'),
        ),
        migrations.DeleteModel(
            name='FilialServico',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 17:13

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0009_auto_20200720_1146'),
        ('cliente', '0013_auto_20200728_1402'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='termo',
            name='id',
        ),
        migrations.AddField(
            model_name='termo',
            name='nome_descritivo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='nome_html',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_termo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo_tipo',
            field=models.CharField(default='CLIENTE.TERMO', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='nome',
            field=models.CharField(default=1, max_length=200, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 17:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0006_auto_20200716_1348'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cargo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionario',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionariologin',
            options={'managed': False},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Cep',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('cep', models.CharField(max_length=10, null=True)),
                ('bairro', models.CharField(max_length=100, null=True)),
                ('rua', models.CharField(max_length=100, null=True)),
                ('latitude_cep', models.CharField(max_length=200, null=True)),
                ('longitude_cep', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'cep',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Data',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('anomesdia', models.IntegerField(primary_key=True, serialize=False)),
                ('anomes', models.IntegerField(null=True)),
                ('ano', models.IntegerField(null=True)),
                ('dat_dia', models.DateTimeField(null=True)),
                ('nr_mes', models.IntegerField(null=True)),
                ('ds_mes', models.CharField(max_length=50, null=True)),
                ('ds_mes_abreviado', models.CharField(max_length=3, null=True)),
                ('nr_dia', models.IntegerField(null=True)),
                ('ds_dia_semana', models.CharField(max_length=50, null=True)),
                ('nr_semana_ano', models.IntegerField(null=True)),
                ('ds_semana_ano', models.CharField(max_length=50, null=True)),
                ('nr_semana_mes', models.IntegerField(null=True)),
                ('ds_semana_mes', models.CharField(max_length=50, null=True)),
                ('nr_bimestre_ano', models.IntegerField(null=True)),
                ('ds_bimestre_ano', models.CharField(max_length=50, null=True)),
                ('nr_trimestre_ano', models.IntegerField(null=True)),
                ('ds_trimestre_ano', models.CharField(max_length=50, null=True)),
                ('nr_quadrimestre_ano', models.IntegerField(null=True)),
                ('ds_quadrimestre_ano', models.CharField(max_length=50, null=True)),
                ('nr_semestre_ano', models.IntegerField(null=True)),
                ('ds_semestre_ano', models.CharField(max_length=50, null=True)),
                ('nr_primeiro_dia_anomes', models.IntegerField(null=True)),
                ('is_ultimo_dia_mes', models.BooleanField(null=True)),
                ('ds_feriado_nacional', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'data',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Empresa',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=100, null=True)),
            ],
            options={
                'db_table': 'empresa',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Erro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=100)),
                ('codigo', models.CharField(max_length=200, null=True)),
                ('descricao', models.TextField(null=True)),
            ],
            options={
                'db_table': 'erro',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Hora',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('descricao', models.CharField(max_length=200, null=True)),
                ('hora', models.IntegerField(null=True)),
                ('minuto', models.IntegerField(null=True)),
                ('hora_minuto', models.TimeField(null=True)),
                ('cd_hora_minuto', models.IntegerField(null=True)),
            ],
            options={
                'db_table': 'hora',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Municipio',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('codigo', models.IntegerField(primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=200)),
            ],
            options={
                'db_table': 'municipio',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Tipo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('codigo', models.IntegerField(null=True)),
                ('tipo', models.CharField(max_length=200, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('descricao', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_tipo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_tipo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_tipo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'tipo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='UF',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('codigo', models.IntegerField(primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('nm_abrev', models.CharField(max_length=2, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_uf_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_uf_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_uf_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'uf',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='municipio',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_municipio_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='municipio',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_municipio_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='municipio',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_municipio_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='municipio',
            name='uf',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.UF'),
        ),
        migrations.AddField(
            model_name='hora',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_hora_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='hora',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_hora_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='hora',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_hora_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='erro',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_erro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='erro',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_erro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='erro',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_erro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='empresa',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_empresa_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='empresa',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_empresa_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='empresa',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_empresa_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='data',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_data_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='data',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_data_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='data',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_data_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='cep',
            name='municipio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Municipio'),
        ),
        migrations.AddField(
            model_name='cep',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_cep_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='cep',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_cep_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='cep',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='core_cep_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AlterUniqueTogether(
            name='tipo',
            unique_together={('codigo', 'tipo')},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0015_auto_20200717_1034'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='estoque',
            name='cd_filial',
        ),
    ]



from compositefk.fields import CompositeForeignKey
from django.db import models
import core.models


class Cliente(core.models.Log, core.models.PessoaLog):
    cpf = models.BigIntegerField(primary_key=True)

    origem_codigo = models.CharField(null=True, max_length=200)
    origem_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.ORIGEM')
    origem = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cliente_origem', to_fields={
        "codigo": "origem_codigo",
        "tipo": "origem_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente'


class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
    codigo = models.IntegerField(default=1, null=True)
    is_principal = models.BooleanField(default=True, null=True)

    apelido = models.CharField(max_length=200, null=True)

    origem_codigo = models.CharField(null=True, max_length=200)
    origem_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.ORIGEM')
    origem = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_endereco_origem', to_fields={
        "codigo": "origem_codigo",
        "tipo": "origem_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        unique_together = ('cliente', 'codigo')
        db_table = 'cliente_endereco'


class Cartao(core.models.Log):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
    cliente_token = models.CharField(max_length=200, null=True)
    cartao_token = models.CharField(max_length=200, null=True)

    primeiros_6 = models.CharField(max_length=6, null=True)
    ultimos_4 = models.CharField(max_length=4, null=True)

    nm_impresso = models.CharField(max_length=200, null=True)
    cpf_titular_numero = models.CharField(max_length=200, null=True)

    dat_val = models.CharField(max_length=5, null=True)
    mes_val = models.IntegerField(null=True)
    ano_val = models.IntegerField(null=True)

    bandeira = models.ForeignKey('cliente.CartaoBandeira', on_delete=models.DO_NOTHING, null=True)

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CARTAO')
    tipo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cartao', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    adquirente_codigo = models.CharField(null=True, max_length=200)
    adquirente_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CARTAO.ADQUIRENTE')
    adquirente = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cartao_adquirente', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_cartao'


class CartaoBandeira(core.models.Log):
    nome = models.CharField(max_length=50, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True)
    imagem = models.FileField(upload_to="bandeiras", default='bandeiras/sem-imagem.jpg', null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_cartaobandeira'


class CartaoBandeiraParcela(core.models.Log):
    bandeira = models.ForeignKey('cliente.CartaoBandeira', on_delete=models.DO_NOTHING, null=True)
    quantidade = models.IntegerField(default=1, null=True)
    is_juros = models.BooleanField(default=False, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_cartaobandeiraparcela'


class Termo(core.models.Log):
    nome = models.CharField(max_length=200, primary_key=True)
    nome_descritivo = models.CharField(max_length=200, null=True)
    nome_html = models.CharField(max_length=200, null=True)
    versao = models.CharField(max_length=50, null=True)
    termo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
    descricao = models.TextField(null=True)
    ordem = models.IntegerField(null=True)

    cliente = models.ManyToManyField('cliente.Cliente', through='cliente.ClienteTermo', through_fields=('termo', 'cliente'))

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.TERMO')
    tipo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_termo', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_termo'


class ClienteTermo(core.models.Log):
    termo = models.ForeignKey('cliente.Termo', on_delete=models.DO_NOTHING, null=True)
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_clientetermo'


class Receita(core.models.Log):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_receita'


class Avaliacao(core.models.Log):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_avaliacao'


class Favorito(core.models.Log):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_favorito'


class Cupom(core.models.Log):
    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cliente_cupom'


# Generated by Django 2.1.7 on 2020-07-13 03:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0002_preco'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bula',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='categoria',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='especialidade',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='grupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='kit',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='preco',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='principioativo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produto',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtobula',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtocategoria',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtoespecialidade',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtogrupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtokit',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtoprincipioativo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtotiporeceita',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='tiporeceita',
            options={'managed': False},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 16:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='servico',
            name='tipo',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo_codigo',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo_tipo',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 18:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0015_termo_ordem'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clientetermo',
            name='cliente',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='termo',
        ),
        migrations.RemoveField(
            model_name='termo',
            name='cliente',
        ),
        migrations.DeleteModel(
            name='ClienteTermo',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ClienteErro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('tipo', models.CharField(max_length=50, null=True)),
                ('ip', models.CharField(max_length=100, null=True)),
                ('descricao', models.TextField(null=True)),
                ('erro', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Erro')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clienteerro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clienteerro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clienteerro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."cliente_erro"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ClienteLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
                ('info_user', models.TextField(null=True)),
                ('info_user_navegador_familia', models.CharField(max_length=200, null=True)),
                ('info_user_navegador_versao', models.CharField(max_length=50, null=True)),
                ('info_user_aparelho_familia', models.CharField(max_length=200, null=True)),
                ('info_user_aparelho_modelo', models.CharField(max_length=200, null=True)),
                ('info_user_os_familia', models.CharField(max_length=200, null=True)),
                ('info_user_os_versao', models.CharField(max_length=50, null=True)),
                ('info_user_is_bot', models.BooleanField(null=True)),
                ('info_user_is_email_client', models.BooleanField(null=True)),
                ('info_user_is_mobile', models.BooleanField(null=True)),
                ('info_user_is_pc', models.BooleanField(null=True)),
                ('info_user_is_tablet', models.BooleanField(null=True)),
                ('info_user_is_touch_capable', models.BooleanField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientelog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientelog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientelog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."cliente_log"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ClienteQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientequery_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientequery_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_clientequery_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."cliente_query"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FornecedorErro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('tipo', models.CharField(max_length=50, null=True)),
                ('ip', models.CharField(max_length=100, null=True)),
                ('descricao', models.TextField(null=True)),
                ('erro', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Erro')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorerro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorerro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorerro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."fornecedor_erro"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FornecedorLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
                ('info_user', models.TextField(null=True)),
                ('info_user_navegador_familia', models.CharField(max_length=200, null=True)),
                ('info_user_navegador_versao', models.CharField(max_length=50, null=True)),
                ('info_user_aparelho_familia', models.CharField(max_length=200, null=True)),
                ('info_user_aparelho_modelo', models.CharField(max_length=200, null=True)),
                ('info_user_os_familia', models.CharField(max_length=200, null=True)),
                ('info_user_os_versao', models.CharField(max_length=50, null=True)),
                ('info_user_is_bot', models.BooleanField(null=True)),
                ('info_user_is_email_client', models.BooleanField(null=True)),
                ('info_user_is_mobile', models.BooleanField(null=True)),
                ('info_user_is_pc', models.BooleanField(null=True)),
                ('info_user_is_tablet', models.BooleanField(null=True)),
                ('info_user_is_touch_capable', models.BooleanField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorlog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorlog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorlog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."fornecedor_log"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FornecedorQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorquery_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorquery_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_fornecedorquery_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."fornecedor_query"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='IndicadorErro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('tipo', models.CharField(max_length=50, null=True)),
                ('ip', models.CharField(max_length=100, null=True)),
                ('descricao', models.TextField(null=True)),
                ('erro', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Erro')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorerro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorerro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorerro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."indicador_erro"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='IndicadorLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
                ('info_user', models.TextField(null=True)),
                ('info_user_navegador_familia', models.CharField(max_length=200, null=True)),
                ('info_user_navegador_versao', models.CharField(max_length=50, null=True)),
                ('info_user_aparelho_familia', models.CharField(max_length=200, null=True)),
                ('info_user_aparelho_modelo', models.CharField(max_length=200, null=True)),
                ('info_user_os_familia', models.CharField(max_length=200, null=True)),
                ('info_user_os_versao', models.CharField(max_length=50, null=True)),
                ('info_user_is_bot', models.BooleanField(null=True)),
                ('info_user_is_email_client', models.BooleanField(null=True)),
                ('info_user_is_mobile', models.BooleanField(null=True)),
                ('info_user_is_pc', models.BooleanField(null=True)),
                ('info_user_is_tablet', models.BooleanField(null=True)),
                ('info_user_is_touch_capable', models.BooleanField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorlog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorlog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorlog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."indicador_log"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='IndicadorQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorquery_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorquery_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_indicadorquery_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."indicador_query"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProcessosErro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('tipo', models.CharField(max_length=50, null=True)),
                ('ip', models.CharField(max_length=100, null=True)),
                ('descricao', models.TextField(null=True)),
                ('erro', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Erro')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoserro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoserro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoserro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."processos_erro"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProcessosLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
                ('info_user', models.TextField(null=True)),
                ('info_user_navegador_familia', models.CharField(max_length=200, null=True)),
                ('info_user_navegador_versao', models.CharField(max_length=50, null=True)),
                ('info_user_aparelho_familia', models.CharField(max_length=200, null=True)),
                ('info_user_aparelho_modelo', models.CharField(max_length=200, null=True)),
                ('info_user_os_familia', models.CharField(max_length=200, null=True)),
                ('info_user_os_versao', models.CharField(max_length=50, null=True)),
                ('info_user_is_bot', models.BooleanField(null=True)),
                ('info_user_is_email_client', models.BooleanField(null=True)),
                ('info_user_is_mobile', models.BooleanField(null=True)),
                ('info_user_is_pc', models.BooleanField(null=True)),
                ('info_user_is_tablet', models.BooleanField(null=True)),
                ('info_user_is_touch_capable', models.BooleanField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoslog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoslog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processoslog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."processos_log"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProcessosQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processosquery_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processosquery_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_processosquery_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."processos_query"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Venda_maisErro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('tipo', models.CharField(max_length=50, null=True)),
                ('ip', models.CharField(max_length=100, null=True)),
                ('descricao', models.TextField(null=True)),
                ('erro', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Erro')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maiserro_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maiserro_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maiserro_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."venda_mais_erro"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Venda_maisLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
                ('info_user', models.TextField(null=True)),
                ('info_user_navegador_familia', models.CharField(max_length=200, null=True)),
                ('info_user_navegador_versao', models.CharField(max_length=50, null=True)),
                ('info_user_aparelho_familia', models.CharField(max_length=200, null=True)),
                ('info_user_aparelho_modelo', models.CharField(max_length=200, null=True)),
                ('info_user_os_familia', models.CharField(max_length=200, null=True)),
                ('info_user_os_versao', models.CharField(max_length=50, null=True)),
                ('info_user_is_bot', models.BooleanField(null=True)),
                ('info_user_is_email_client', models.BooleanField(null=True)),
                ('info_user_is_mobile', models.BooleanField(null=True)),
                ('info_user_is_pc', models.BooleanField(null=True)),
                ('info_user_is_tablet', models.BooleanField(null=True)),
                ('info_user_is_touch_capable', models.BooleanField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maislog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maislog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maislog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."venda_mais_log"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Venda_maisQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maisquery_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maisquery_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='log_venda_maisquery_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': '"log"."venda_mais_query"',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 16:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.AlterField(
            model_name='funcionariologin',
            name='origem_tipo',
            field=models.CharField(default='USR.ORIGEM', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='funcionariologin',
            name='tipo_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 20:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0010_cep_cep_form'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cep',
            old_name='bairro',
            new_name='bairro_cep',
        ),
        migrations.RenameField(
            model_name='cep',
            old_name='rua',
            new_name='rua_cep',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0013_auto_20200717_1046'),
        ('produto', '0016_remove_estoque_cd_filial'),
    ]

    operations = [
        migrations.AddField(
            model_name='estoque',
            name='cd_filial',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
        ('fornecedor', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Bula',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto_bula',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Categoria',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('categoria_pai', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria')),
            ],
            options={
                'db_table': 'produto_categoria',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Especialidade',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto_especialidade',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Grupo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto_grupo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Kit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto_kit',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PrincipioAtivo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto_principioativo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Produto',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
            ],
            options={
                'db_table': 'produto',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoBula',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('bula', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Bula')),
            ],
            options={
                'db_table': 'produto_produtobula',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoCategoria',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('categoria', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria')),
            ],
            options={
                'db_table': 'produto_produtocategoria',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoEspecialidade',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('especialidade', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Especialidade')),
            ],
            options={
                'db_table': 'produto_produtoespecialidade',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoGrupo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('grupo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Grupo')),
            ],
            options={
                'db_table': 'produto_produtogrupo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoKit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('kit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Kit')),
            ],
            options={
                'db_table': 'produto_produtokit',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoPrincipioAtivo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
            ],
            options={
                'db_table': 'produto_produtoprincipioativo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoTipoReceita',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
            ],
            options={
                'db_table': 'produto_produtotiporeceita',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Tipo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tipo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tipo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tipo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'produto_tipo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='TipoReceita',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tiporeceita_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tiporeceita_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_tiporeceita_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'produto_tiporeceita',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='produtotiporeceita',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtotiporeceita_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtotiporeceita',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtotiporeceita_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtotiporeceita',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtotiporeceita_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtotiporeceita',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtotiporeceita',
            name='tipo_receita',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.TipoReceita'),
        ),
        migrations.AddField(
            model_name='produtoprincipioativo',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoprincipioativo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoprincipioativo',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoprincipioativo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoprincipioativo',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoprincipioativo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoprincipioativo',
            name='principio_ativo',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.PrincipioAtivo'),
        ),
        migrations.AddField(
            model_name='produtoprincipioativo',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtokit',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtokit_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtokit',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtokit_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtokit',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtokit_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtokit',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtogrupo',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtogrupo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtogrupo',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtogrupo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtogrupo',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtogrupo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtogrupo',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtoespecialidade',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoespecialidade_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoespecialidade',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoespecialidade_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoespecialidade',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoespecialidade_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoespecialidade',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtocategoria',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtocategoria_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtocategoria',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtocategoria_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtocategoria',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtocategoria_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtocategoria',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtobula',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtobula_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtobula',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtobula_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtobula',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtobula_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtobula',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produto',
            name='bula',
            field=models.ManyToManyField(through='produto.ProdutoBula', to='produto.Bula'),
        ),
        migrations.AddField(
            model_name='produto',
            name='categoria',
            field=models.ManyToManyField(through='produto.ProdutoCategoria', to='produto.Categoria'),
        ),
        migrations.AddField(
            model_name='produto',
            name='especialidade',
            field=models.ManyToManyField(through='produto.ProdutoEspecialidade', to='produto.Especialidade'),
        ),
        migrations.AddField(
            model_name='produto',
            name='fabricante',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='fornecedor.Fabricante'),
        ),
        migrations.AddField(
            model_name='produto',
            name='grupo',
            field=models.ManyToManyField(through='produto.ProdutoGrupo', to='produto.Grupo'),
        ),
        migrations.AddField(
            model_name='produto',
            name='kit',
            field=models.ManyToManyField(through='produto.ProdutoKit', to='produto.Kit'),
        ),
        migrations.AddField(
            model_name='produto',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produto_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produto',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produto_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produto',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produto_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produto',
            name='principio_ativo',
            field=models.ManyToManyField(through='produto.ProdutoPrincipioAtivo', to='produto.PrincipioAtivo'),
        ),
        migrations.AddField(
            model_name='produto',
            name='tipo_produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Tipo'),
        ),
        migrations.AddField(
            model_name='produto',
            name='tipo_receita',
            field=models.ManyToManyField(through='produto.ProdutoTipoReceita', to='produto.TipoReceita'),
        ),
        migrations.AddField(
            model_name='principioativo',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_principioativo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='principioativo',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_principioativo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='principioativo',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_principioativo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='kit',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_kit_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='kit',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_kit_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='kit',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_kit_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='grupo',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_grupo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='grupo',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_grupo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='grupo',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_grupo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='especialidade',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_especialidade_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='especialidade',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_especialidade_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='especialidade',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_especialidade_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='categoria',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_categoria_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='categoria',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_categoria_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='categoria',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_categoria_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='bula',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_bula_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='bula',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_bula_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='bula',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_bula_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
    ]



from django.urls import re_path, include
from core.views import InteligerView

urlpatterns = [
    re_path(r'cliente/', include(('core.cliente.urls', 'core.cliente'), namespace='cliente')),
    re_path(r'filial/', include(('core.filial.urls', 'core.filial'), namespace='filial')),
    re_path(r'fornecedor/', include(('core.fornecedor.urls', 'core.fornecedor'), namespace='fornecedor')),
    re_path(r'funcionario/', include(('core.funcionario.urls', 'core.funcionario'), namespace='funcionario')),
    re_path(r'log/', include(('core.log.urls', 'core.log'), namespace='log')),
    re_path(r'produto/', include(('core.produto.urls', 'core.produto'), namespace='produto')),
    re_path(r'sistema/', include(('core.sistema.urls', 'core.sistema'), namespace='sistema')),
    re_path(r'usr/', include(('core.usr.urls', 'core.usr'), namespace='usr')),

    re_path(r'atualizar$', InteligerView.as_view(), name='sistema_atualizar'),
]
